# pyRona
A python implementation of "Risk of non Adaptedness" method (with a bit of R too!)

[![Build Status](https://travis-ci.org/StuntsPT/pyRona.svg?branch=master)](https://travis-ci.org/StuntsPT/pyRona) [![Documentation Status](https://readthedocs.org/projects/pyrona/badge/?version=latest)](http://pyrona.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/pyRona.svg)](https://badge.fury.io/py/pyRona) [![DOI](https://zenodo.org/badge/73514698.svg)](https://zenodo.org/badge/latestdoi/73514698)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/e7952d390d4644d1aae482f94d340695)](https://www.codacy.com/app/f.pinamartins/pyRona?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=StuntsPT/pyRona&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://api.codacy.com/project/badge/Coverage/e7952d390d4644d1aae482f94d340695)](https://www.codacy.com/app/f.pinamartins/pyRona?utm_source=github.com&utm_medium=referral&utm_content=StuntsPT/pyRona&utm_campaign=Badge_Coverage)


## pyRona manual

*pyRona* is not yet fully documented, but you can find the manual [here](http://pyrona.readthedocs.io/en/latest/).


## Baypass_workflow.R

If you came here looking for a way to automate the *BayPass* analysis, you should be especially interested in it's [manual section](http://pyrona.readthedocs.io/en/latest/baypass/). You can find the script [here](https://gitlab.com/StuntsPT/pyRona/blob/master/pyRona/R/Baypass_workflow.R).


## LFMM and LFMM2 helper scripts

If you came here looking for a way to automate *LFMM*/*LFMM2* analysws, you should be especially interested in it's [manual section](http://pyrona.readthedocs.io/en/latest/lfmm/). You can find the scripts for both *LFMM* and *LFMM2* [here](https://gitlab.com/StuntsPT/pyRona/blob/master/pyRona/R/).


## Installation

Installing *pyRona* can be as simple as typing `pip3 install pyRona` from the command line. For more information, and platform specific instructions, please consult the [relevant manual section](http://pyrona.readthedocs.io/en/latest/install/).


## Citation

If you use `pyRona` please cite our ~~pre-print: [New insights on adaptation and population structure of cork oak using genotyping by sequencing](https://doi.org/10.1101/263160)~~ paper: [New insights into adaptation and population structure of cork oak using genotyping by sequencing](https://onlinelibrary.wiley.com/doi/abs/10.1111/gcb.14497)


## License

*pyRona* is licensed under the [GNU GPLv3](https://www.gnu.org/licenses/gpl-3.0-standalone.html).
